# Name: kinspy
# Describes: provide convenient functions and constants
# Version: v1.0.3
# Date: 2021-04-25
# Author: Yunxiao Zhang
# E-mail: yunxiao9277@gmail.com

from numpy import sqrt, sin, cos, exp, log
from numpy import pi, e
from numpy import zeros, ones